@@ -5,3 +5,8 @@ from django.views import View
 class MiddlewareTestView(View):
     def get(self, request):
         return HttpResponse("OK")
+
+
+class MiddlewareTestErrorView(View):
+    def get(self, request):
+        raise Exception("Not OK")
